package betterquesting.api2.client.gui.misc;

import betterquesting.api.utils.RenderUtils;
import javax.annotation.Nonnull;

/* loaded from: betterquesting_api2_client_gui_misc.jar:betterquesting/api2/client/gui/misc/GuiRectLerp.class */
public class GuiRectLerp implements IGuiRect {
    private IGuiRect startRect;
    private IGuiRect targetRect;
    private long duration = 200;
    private long et = System.currentTimeMillis();
    private final ProxyRect pxRect;

    public GuiRectLerp(@Nonnull IGuiRect start) {
        this.startRect = start;
        this.targetRect = start;
        this.pxRect = new ProxyRect(start);
    }

    public void lerpTo(@Nonnull IGuiRect target, long time) {
        if (time <= 0) {
            return;
        }
        this.targetRect = target;
        this.duration = time;
        this.et = System.currentTimeMillis();
        this.pxRect.changeReference(target);
    }

    public void snapTo(@Nonnull IGuiRect target) {
        this.startRect = target;
        this.targetRect = target;
        this.et = System.currentTimeMillis();
        this.pxRect.changeReference(target);
    }

    public IGuiRect getProxyRect() {
        return this.pxRect;
    }

    public boolean isIdle() {
        if (this.startRect == this.targetRect) {
            return true;
        }
        if (System.currentTimeMillis() - this.et >= this.duration) {
            this.startRect = this.targetRect;
            return true;
        }
        return false;
    }

    @Override // betterquesting.api2.client.gui.misc.IGuiRect
    public int getX() {
        return isIdle() ? this.targetRect.getX() : (int) Math.round(RenderUtils.lerpDouble(this.startRect.getX(), this.targetRect.getX(), (System.currentTimeMillis() - this.et) / this.duration));
    }

    @Override // betterquesting.api2.client.gui.misc.IGuiRect
    public int getY() {
        return isIdle() ? this.targetRect.getY() : (int) Math.round(RenderUtils.lerpDouble(this.startRect.getY(), this.targetRect.getY(), (System.currentTimeMillis() - this.et) / this.duration));
    }

    @Override // betterquesting.api2.client.gui.misc.IGuiRect
    public int getWidth() {
        return isIdle() ? this.targetRect.getWidth() : (int) Math.round(RenderUtils.lerpDouble(this.startRect.getWidth(), this.targetRect.getWidth(), (System.currentTimeMillis() - this.et) / this.duration));
    }

    @Override // betterquesting.api2.client.gui.misc.IGuiRect
    public int getHeight() {
        return isIdle() ? this.targetRect.getHeight() : (int) Math.round(RenderUtils.lerpDouble(this.startRect.getHeight(), this.targetRect.getHeight(), (System.currentTimeMillis() - this.et) / this.duration));
    }

    @Override // betterquesting.api2.client.gui.misc.IGuiRect
    public int getDepth() {
        return this.targetRect.getDepth();
    }

    @Override // betterquesting.api2.client.gui.misc.IGuiRect
    public IGuiRect getParent() {
        return this.targetRect.getParent();
    }

    @Override // betterquesting.api2.client.gui.misc.IGuiRect
    public void setParent(IGuiRect rect) {
        this.targetRect.setParent(rect);
    }

    @Override // betterquesting.api2.client.gui.misc.IGuiRect
    public boolean contains(int x, int y) {
        return this.targetRect.contains(x, y);
    }

    @Override // java.lang.Comparable
    public int compareTo(@Nonnull IGuiRect o) {
        return this.targetRect.compareTo(o);
    }
}
